aboutsummaryrefslogtreecommitdiffstats
path: root/sound
diff options
authorPeter Ujfalusi <peter.ujfalusi@linux.intel.com>2026-05-20 18:06:39 +0300
committerMark Brown <broonie@kernel.org>2026-05-22 00:16:32 +0100
commitfdfbd9ff86a145f09978ab49305ed7acfad66a1d (patch)
treeb3061cd3d738d5a5613f136306d5465731c25d44 /sound
parent978152b2cab5375f5f8f03871bd4a1f1842dd0e4 (diff)
downloadlinux-next-history-fdfbd9ff86a145f09978ab49305ed7acfad66a1d.tar.gz
ASoC: SOF: Intel: lnl: Enable offload for UAOL link
The handling of UAOL (USB Audio Offload Link) is similar to SSP and DMIC, it is handled by the DSP firmware. Set the offload enable for it similar to SSP and DMIC. Signed-off-by: Peter Ujfalusi <peter.ujfalusi@linux.intel.com> Reviewed-by: Bard Liao <yung-chuan.liao@linux.intel.com> Reviewed-by: Kai Vehmanen <kai.vehmanen@linux.intel.com> Link: https://patch.msgid.link/20260520150639.25301-3-peter.ujfalusi@linux.intel.com Signed-off-by: Mark Brown <broonie@kernel.org>
Diffstat (limited to 'sound')
-rw-r--r--sound/soc/sof/intel/lnl.c3
1 files changed, 2 insertions, 1 deletions
diff --git a/sound/soc/sof/intel/lnl.c b/sound/soc/sof/intel/lnl.c
index 19f753dca30b1..83703ebc6385b 100644
--- a/sound/soc/sof/intel/lnl.c
+++ b/sound/soc/sof/intel/lnl.c
@@ -20,11 +20,12 @@
#include "lnl.h"
#include <sound/hda-mlink.h>
/* Configure DSP offload for DMIC/SSP */
static void hdac_bus_set_dsp_offload(struct hdac_bus *bus, bool enable)
{
hdac_bus_eml_enable_offload(bus, true, AZX_REG_ML_LEPTR_ID_INTEL_SSP, enable);
hdac_bus_eml_enable_offload(bus, true, AZX_REG_ML_LEPTR_ID_INTEL_DMIC, enable);
+ hdac_bus_eml_enable_offload(bus, true, AZX_REG_ML_LEPTR_ID_INTEL_UAOL, enable);
}
static int lnl_hda_dsp_probe(struct snd_sof_dev *sdev)
@@ -20,11 +20,12 @@
#include "lnl.h"
#include <sound/hda-mlink.h>
-/* Configure DSP offload for DMIC/SSP */
+/* Configure DSP offload for DMIC/SSP/UAOL */
static void hdac_bus_set_dsp_offload(struct hdac_bus *bus, bool enable)
{